jaxsne package
==============

Module contents
---------------

.. automodule:: jaxsne
   :members:
   :show-inheritance:
   :undoc-members:

jaxsne.metric module
--------------------

.. automodule:: jaxsne.metric
   :members:
   :show-inheritance:
   :undoc-members:

jaxsne.measure module
---------------------

.. automodule:: jaxsne.measure
   :members:
   :show-inheritance:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
